# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v0.0.2-alpha.2] - 2024-06-26
### BREAKING CHANGES
- due to [`f38ab2f`](https://github.com/HydroRoll-Team/HydroRollCore/commit/f38ab2f073cc6599ef4d4248a00fe07a74d0e63b) - revert for two previous commit *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*:

  revert for two previous commit


### New Features
- [`09413f0`](https://github.com/HydroRoll-Team/HydroRollCore/commit/09413f06949b421a1c5b0cc05d70d84b184d3397) - **rust**: wrap_pyfunction "process_rule_pack" in libcore module *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`fdee348`](https://github.com/HydroRoll-Team/HydroRollCore/commit/fdee34884c29216db2a6bdb7e5c714af2e780777) - **cli|project**: add Cli class && hrc entry in project.scripts section *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*

### Bug Fixes
- [`416f5f0`](https://github.com/HydroRoll-Team/HydroRollCore/commit/416f5f04121677784b783c37dcf33b444b7c8aa2) - **ci**: fix "failed to run custom build command" *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*

### Refactors
- [`6e555bf`](https://github.com/HydroRoll-Team/HydroRollCore/commit/6e555bf5c16815cf0982ba5891e3bbe09444091a) - **filetree**: docs -> document, features -> feature, dev -> development *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`a2477b2`](https://github.com/HydroRoll-Team/HydroRollCore/commit/a2477b28057251c4685dbf0b56359dee7b595bfa) - **filetree**: rename package's namespace as `hrc` *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*

### Chores
- [`272310e`](https://github.com/HydroRoll-Team/HydroRollCore/commit/272310ebd50978941f9e604fa217256b8a92fdbc) - **docs**: update file *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`28a7b2e`](https://github.com/HydroRoll-Team/HydroRollCore/commit/28a7b2ecd90e7e67427682a99b8616e13042b4ab) - refresh source tree files *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`ab3ea64`](https://github.com/HydroRoll-Team/HydroRollCore/commit/ab3ea641736657fd65fef673940022b8f671d83a) - Update README.rst *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`aef878f`](https://github.com/HydroRoll-Team/HydroRollCore/commit/aef878f63472bc5deadd4851b3905a4fdbdbe912) - Update README.rst *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`ea840bb`](https://github.com/HydroRoll-Team/HydroRollCore/commit/ea840bbc63843bd605a00da31f80241a4f2a9746) - **deps|rust**: add clap dependencies *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`d241a9a`](https://github.com/HydroRoll-Team/HydroRollCore/commit/d241a9a0e743ff66a2961603dd44f398fb683885) - **format**: ruff lint code *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`543c06f`](https://github.com/HydroRoll-Team/HydroRollCore/commit/543c06fb61bf8c5d7bc83030d1ab45a0d5430620) - **deps**: delete features of pyo3 in Cargo.toml *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`62b9be2`](https://github.com/HydroRoll-Team/HydroRollCore/commit/62b9be2ef081517eb17cd1f32bc432ccbfda9e83) - **ci|deps**: use python3.9 && change into abi3-py37 ^^ *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`d3d289b`](https://github.com/HydroRoll-Team/HydroRollCore/commit/d3d289bcfb9252bec6fc6db3f0ce408905ac5266) - **deps**: update features of pyo3 *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`eba876a`](https://github.com/HydroRoll-Team/HydroRollCore/commit/eba876aabb7335c8e3330cec924e74765c1126d7) - **deps**: delete features of pyo3 *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`02dfe51`](https://github.com/HydroRoll-Team/HydroRollCore/commit/02dfe519450784f0e60e5076a9c476dda2f50827) - **deps**: update features of pyo3 *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`2e5b7e8`](https://github.com/HydroRoll-Team/HydroRollCore/commit/2e5b7e8ab75e0d80066d1ef5619d10fe827fd5a8) - **deps**: remove pip deps from dev group *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`dcadac7`](https://github.com/HydroRoll-Team/HydroRollCore/commit/dcadac73813291a86a4ab3aca44706fc9b8e3b5e) - **docs**: add structures.svg and contributing guidance *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`97bf2ba`](https://github.com/HydroRoll-Team/HydroRollCore/commit/97bf2ba7a00cb594b4e17a85d0e3630f0f50a97d) - **docs**: update README.rst *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`08025ec`](https://github.com/HydroRoll-Team/HydroRollCore/commit/08025ec6b32078840e26d4584a7e79ad12cd62f2) - **project**: bump version to 0.0.2-alpha.2 *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*

[v0.0.2-alpha.2]: https://github.com/HydroRoll-Team/HydroRollCore/compare/v99.99.99...v0.0.2-alpha.2
